Learn R Programming

PlasmaMutationDetector2 (version 1.1.11)

positions_ranges: The package provide the positions and ranges computed for the Ion AmpliSeq<U+2122> Colon and Lung Cancer Panel v2 as a Rdata file positions_ranges.rda.

Description

This file contains 4 variables

  • pos_ind, vector of chars, of the form chrN:XXXXXXXXX defining genomic positions of the Ion AmpliSeq<U+2122> Colon and Lung Cancer Panel v2

  • pos_snp, vector of chars, of the form chrN:XXXXXXXXX defining the known snp genomic positions

  • pos_ranges, GRanges object, describing the 92 amplicons of the Ion AmpliSeq<U+2122> Colon and Lung Cancer Panel v2

Usage

data(positions_ranges)

Arguments

References

Analysis of base-position error rate of next-generation sequencing to detect tumor mutations in circulating DNA N. P<U+00E9>cuchet, Y. Rozenholc, E. Zonta, D. Pietraz, A. Didelot, P. Combe, L. Gibault, J-B. Bachet, V. Taly, E. Fabre, H. Blons, P. Laurent-Puig in Clinical Chemistry

Novel hybridization- and tag-based error-corrected method for sensitive ctDNA mutation detection using ion semiconductor sequencing Kjersti Tjensvoll, Morten Lapin, Bj<U+00F8>rnar Gilje, Herish Garresori, Satu Oltedal, Rakel Brendsdal Forthun, Anders Molven, Yves Rozenholc and Oddmund Nordg<U+00E5>rd in Scientific Reports

See Also

Prepare_Library